package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.fire.domain.DemMicroStation;
import com.usky.fire.mapper.DemMicroStationMapper;
import com.usky.fire.service.DemMicroStationService;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * <p>
 * 微型消防站 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-10-24
 */
@Service
public class DemMicroStationServiceImpl extends AbstractCrudService<DemMicroStationMapper, DemMicroStation> implements DemMicroStationService {

    @Override
    public CommonPage<Map<String, Object>> microStationList(String squadron, String stationName, Integer id, Integer pageNum, Integer pageSize) {
        List<Map<String, Object>> list = new ArrayList<>();
        IPage<DemMicroStation> page = new Page<>(pageNum, pageSize);
        LambdaQueryWrapper<DemMicroStation> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(DemMicroStation::getId, DemMicroStation::getBranchName, DemMicroStation::getSquadron,
                DemMicroStation::getStationName, DemMicroStation::getCompanyNature, DemMicroStation::getAddress,
                DemMicroStation::getLocation, DemMicroStation::getFixedPhone, DemMicroStation::getChargeName,
                DemMicroStation::getChargePhone, DemMicroStation::getStationType)
                .eq(DemMicroStation::getDeleteFlag, 0)
                .like(StringUtils.isNotBlank(squadron), DemMicroStation::getSquadron, squadron)
                .like(StringUtils.isNotBlank(stationName), DemMicroStation::getStationName, stationName)
                .orderByDesc(DemMicroStation::getId);
        page = this.page(page, queryWrapper);
        if (CollectionUtils.isNotEmpty(page.getRecords())) {
            for (int i = 0; i < page.getRecords().size(); i++) {
                Map<String, Object> map = new HashMap<>();
                map.put("id", page.getRecords().get(i).getId());
                map.put("branchName", page.getRecords().get(i).getBranchName());
                map.put("squadron", page.getRecords().get(i).getSquadron());
                map.put("stationName", page.getRecords().get(i).getStationName());
                map.put("companyNature", page.getRecords().get(i).getCompanyNature());
                map.put("address", page.getRecords().get(i).getAddress());
                map.put("location", page.getRecords().get(i).getLocation());
                map.put("fixedPhone", page.getRecords().get(i).getFixedPhone());
                map.put("chargeName", page.getRecords().get(i).getChargeName());
                map.put("chargePhone", page.getRecords().get(i).getChargePhone());
                map.put("stationType", page.getRecords().get(i).getStationType());
                list.add(map);
            }
        }
        return new CommonPage<>(list, page.getTotal(), pageSize, pageNum);
    }

    @Override
    public void updateMicroStation(DemMicroStation demMicroStation) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd :hh:mm:ss");
        demMicroStation.setUpdateTime(dateFormat.format(new Date()));
        this.updateById(demMicroStation);
    }

    @Override
    public void delMicroStation(Integer id) {
        DemMicroStation demMicroStation = new DemMicroStation();
        demMicroStation.setId(id);
        demMicroStation.setDeleteFlag("1");
        this.updateById(demMicroStation);
    }

    @Override
    public List<Map<String, Object>> microStationDroplistList(String branchName) {
        List<Map<String, Object>> list = new ArrayList<>();
        LambdaQueryWrapper<DemMicroStation> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(DemMicroStation::getSquadron)
                .eq(DemMicroStation::getDeleteFlag, "0")
                .eq(StringUtils.isNotBlank(branchName), DemMicroStation::getBranchName, branchName)
                .groupBy(DemMicroStation::getSquadron);
        List<DemMicroStation> list1 = this.list(queryWrapper);
        if (CollectionUtils.isNotEmpty(list1)) {
            for (int i = 0; i < list1.size(); i++) {
                Map<String, Object> map = new HashMap<>();
                map.put("squadron", list1.get(i).getSquadron());
                list.add(map);
            }
        }
        return list;
    }

}
